@@ -282,7 +282,7 @@ class FlaskFunctions:
             db.close()
             print(const.IP)
             print(HTTPPORT)
-            app.run(host='192.168.2.74', port=HTTPPORT, debug=const.HTTPDEBUG)
+            app.run(host= ip, port=HTTPPORT, debug=const.HTTPDEBUG)
         except Exception as e:
             logger.error('there has been an exception in Data Package service startup ' + str(e))
             return -1
